@@ -20,21 +20,13 @@
  * 	Emmanuel Pacaud <emmanuel@gnome.org>
  */
 
-
 #ifndef LSM_DOM_H
 #define LSM_DOM_H
 
-#include <glib-object.h>
+#include <lsm.h>
 
 G_BEGIN_DECLS
 
-typedef struct {
-	double x;
-	double y;
-	double width;
-	double height;
-} LsmBox;
-
 typedef struct _LsmDomNode LsmDomNode;
 typedef struct _LsmDomElement LsmDomElement;
 typedef struct _LsmDomDocument LsmDomDocument;
